using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Mvc;
using System;

namespace API_Rest.Controllers
{

    [Authorize]
    [ApiController]
    [Route("api/[controller]")]
    public class WeatherForecastController : ControllerBase
    {

        
        public WeatherForecastService _wfs { get; set; }

        public IEnumerable<WeatherForecast> WeatherForecasts { get; set; }
        public WeatherForecast wf { get; set; }
        private readonly ILogger<WeatherForecastController> _logger;

        public WeatherForecastController(ILogger<WeatherForecastController> logger, WeatherForecastService wfs)
        {
            _wfs = wfs;
            _logger = logger;
        }

        [HttpGet("GetAll/")]
        [Authorize]
        public async Task<IEnumerable<WeatherForecast>> GetAll()
        {
            WeatherForecasts = _wfs.Get();
            return WeatherForecasts;

        }

        [HttpGet]
        [Authorize]
        public async Task<IActionResult> Get(int page, int pageSize)
        {

            WeatherForecasts = _wfs.Get();
            var pageResuts = WeatherForecasts.Skip(page).Take(pageSize);
            return Ok(pageResuts); 

        }

        [HttpGet("GetOne/{id}")]
        [Authorize]
        public async Task<ActionResult<WeatherForecast>> GetOne(long id)
        {

            wf = _wfs.GetOne(id);
            if (wf != null)
            {
                return Ok(wf);
            }
            return BadRequest();

        }

        [HttpPut("Update/{id}")]
        [Authorize]
        public async Task<ActionResult<WeatherForecast>> UpdateWeatherForcast(int id, WeatherForecast weatherForcast) {
            _wfs.UpdateWeatherForcast(id, weatherForcast);
            return Ok();
        }

        [HttpPost("{WeatherForecast wf}")]
        [Authorize]
        public async Task<ActionResult<WeatherForecast>> Post(WeatherForecast wf)
        {
            _wfs.Post(wf);
            return CreatedAtAction(nameof(Created), new { date = wf.Date }, wf);
        }


        [HttpDelete("DeleteOne/{id}")]
        [Authorize]
        public async Task<ActionResult> DeleteOne(long id)
        {
            if (_wfs.DeleteOne(id))
            {
                return Ok();
            }
            return BadRequest();
        }
    }
}
